<?php 
/**
Test si l'utilisateur courant est un administrateur
 * @return boolean : TRUE si l'utilisateur est administrateur, FALSE sinon
**/
function current_user_is_admin () {
  $current_user = wp_get_current_user();
  return ( array_search('administrator', $current_user->roles) !== False );
}
/**
Chargement du thème
**/
if ( ! function_exists( 'basics_setup' ) ) :
function basics_setup() {
	load_theme_textdomain('basics');
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
	add_theme_support( 'post-formats', array ( 'aside', 'gallery', 'quote', 'image', 'video' ) );
	add_post_type_support( 'page', 'excerpt' );
}
endif;
add_action( 'after_setup_theme', 'basics_setup' );

if ( ! isset ( $content_width) )
    $content_width = 1000;

add_filter( 'http_request_host_is_external', function() { return true; });

//STYLES basics
function basics_styles() {
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/libs/bootstrap/css/bootstrap.min.css',  array(), ' ', 'screen' );
	wp_enqueue_style( 'ionicons', get_template_directory_uri() . '/libs/ionicons/css/ionicons.min.css');
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css');
	wp_enqueue_style( 'fonts', 'https://fonts.googleapis.com/css?family=Quicksand:400,600,700|Raleway:400,700&display=swap' );
	wp_enqueue_style( 'style', get_template_directory_uri() . '/style.css' );
	wp_enqueue_script ('jquery');
}
add_action( 'wp_enqueue_scripts', 'basics_styles' );

remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
remove_action( 'wp_print_styles', 'print_emoji_styles' );
remove_action( 'admin_print_styles', 'print_emoji_styles' ); 

function basics_js() {
	
	wp_register_script('bootstrap', get_template_directory_uri() . '/libs/bootstrap/js/bootstrap.min.js','','1.0',true);
	wp_enqueue_script( 'bootstrap' );
	wp_register_script('easing', get_template_directory_uri() . '/js/jquery.easing.min.js','','1.0',true);
	wp_enqueue_script( 'easing' );
	wp_register_script('main', get_template_directory_uri() . '/js/main.js','','1.0',true);
	wp_enqueue_script( 'main' );
	wp_register_script('aniview', get_template_directory_uri() . '/js/jquery.aniview.js','','1.0',true);
	wp_enqueue_script( 'aniview' );
	if ( is_home() || is_search() || is_category() || is_tag () || is_author() || is_archive() || is_page('evenements') ) : 
		wp_enqueue_script('jquery-masonry');
		wp_register_script('infinite', get_template_directory_uri() . '/js/scroll.js','','1.0',true);
		wp_enqueue_script( 'infinite' );
		wp_register_script('scroll', get_template_directory_uri() . '/js/scroll_action.js','','1.0',true);
		wp_enqueue_script( 'scroll' );
	endif;
}
add_action( 'wp_enqueue_scripts', 'basics_js' ); 


// THEME basics

if ( ! function_exists( '_wp_render_title_tag' ) ) {
	function theme_slug_render_title() {
?>
<title><?php wp_title( '|', true, 'right' ); ?></title>
<?php
	}
	add_action( 'wp_head', 'theme_slug_render_title' );
}

//CSS admin

function basics_adminCSS() {
	echo '<link rel="stylesheet" type="text/css" href="'.get_template_directory_uri() .'/admin/wp-admin.css"/>';
}
add_action('admin_head', 'basics_adminCSS');

// Enable thumbnails

	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size (800, 533, true); 
	
function add_image_sizes()
{ 
	add_image_size( 'headline', 1200, 800, true );   
	add_image_size( 'medium', 600, 400, true );   
	add_image_size( 'small', 300, 200, true );         
	add_image_size( 'avatar', 200, 200, true );         
}
add_action('after_setup_theme', 'add_image_sizes');



//Filter authors on posts (dashboard)
add_action( 'restrict_manage_posts', 'basics_authors_manage_posts' );
function basics_authors_manage_posts() {
	global $wp_roles;
	$roles = $wp_roles->roles;
	if ( ! empty( $roles ) ) {
		echo '<select name="author"><option value="">All users</option>';
		foreach ( $roles as $role => $data ) {
			$users = get_users('orderby=display_name&role=' . $role);
			if ( ! empty( $users ) ) {
				echo '<optgroup label="' . esc_attr( ucfirst( $role ) ) . 's">';
				foreach ( $users as $user ) {
					echo '<option value="' . $user->ID . '"' . ( isset( $_GET['author'] ) && $user->ID == $_GET['author'] ? ' selected' : '' ) . '>' . $user->data->display_name . '</option>';
				}
				echo '</optgroup>';
			}
		}
		echo '</select>';
	}
}
	
// Menus

register_nav_menu('top', 'Top menu');


if ( ! function_exists( 'post_is_in_descendant_category' ) ) {
	function post_is_in_descendant_category( $cats, $_post = null ) {
		foreach ( (array) $cats as $cat ) {
			// get_term_children() accepts integer ID only
			$descendants = get_term_children( (int) $cat, 'category' );
			if ( $descendants && in_category( $descendants, $_post ) )
				return true;
		}
		return false;
	}
}

// Stop images getting wrapped up in p tags when they get dumped out with the_content() for easier theme styling
function basics_remove_img_ptags($content){
	return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}
add_filter('the_content', 'basics_remove_img_ptags');

//COMPATIBILITY---SECURITY

// Call Googles HTML5 Shim, but only for users on old versions of IE
function basics_IEhtml5_shim () {
	global $is_IE;
	if ($is_IE)
	echo '<!--[if lt IE 9]><script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script><![endif]-->';
}
add_action('wp_head', 'basics_IEhtml5_shim');

// Remove the version number of WP
// Warning - this info is also available in the readme.html file in your root directory - delete this file!
remove_action('wp_head', 'wp_generator');

// Obscure login screen error messages
function basics_login_obscure(){ return '<strong>Sorry</strong>: Think you have gone wrong somwhere!';}
add_filter( 'login_errors', 'basics_login_obscure' );

// Disable the theme / plugin text editor in Admin
define('DISALLOW_FILE_EDIT', true);

//DELETE Really Simple Discovery
remove_action('wp_head', 'rsd_link');


//LOGIN basics

function login_basics() {
	 wp_enqueue_style( 'custom-login', get_template_directory_uri() . '/admin/wp-login.css' );
}
add_action( 'login_enqueue_scripts', 'login_basics' );

function login_logo_url() {
    return home_url();
}
add_filter( 'login_headerurl', 'login_logo_url' );

function login_logo_url_title() {
    return 'basics';
}
add_filter( 'login_headertext', 'login_logo_url_title' );

function basics_login_head() {
	$blog_url = home_url();
	echo '<link rel="shortcut icon" href="'. get_template_directory_uri() .'/img/favicon/favicon.ico"/>';
}
add_action("login_head", "basics_login_head");

function basics_admin_head() {
	echo '<link rel="shortcut icon" href="'. get_template_directory_uri() .'/img/favicon/favicon.ico"/>';
}
add_action('admin_head', 'basics_admin_head');

add_action('wp_logout','basics_home');
function basics_home(){
  wp_redirect( home_url() );
  exit();
}

//Mode d'emploi sur le dashboard

function remove_admin_bar_links() {
    global $wp_admin_bar;
    $wp_admin_bar->remove_menu('about');           
    $wp_admin_bar->remove_menu('wporg');         
    $wp_admin_bar->remove_menu('documentation'); 
    $wp_admin_bar->remove_menu('support-forums'); 
    $wp_admin_bar->remove_menu('feedback'); 
    $wp_admin_bar->remove_menu('comments'); 
}
add_action( 'wp_before_admin_bar_render', 'remove_admin_bar_links' );

/* Supprimer les widgets */
 function remove_default_widgets() {
     unregister_widget('WP_Widget_Meta'); //Widget Meta
     unregister_widget('WP_Widget_Search'); //Widget Rechercher
     unregister_widget('WP_Widget_Recent_Comments'); //Widget Commentaires recents
	 unregister_widget('WP_Widget_Archives'); //Widget Archives
 }
 add_action('widgets_init', 'remove_default_widgets', 11);

function remove_admin_menu_items() {
	$remove_menu_items = array(__('Comments'));
	global $menu;
	end ($menu);
	while (prev($menu)){
		$item = explode(' ',$menu[key($menu)][0]);
		if(in_array($item[0] != NULL?$item[0]:"" , $remove_menu_items)){
		unset($menu[key($menu)]);}
	}
}
add_action('admin_menu', 'remove_admin_menu_items');

/* Cacher les elements de menu sidebar left */

function disable_default_dashboard_widgets() {
	remove_meta_box('dashboard_recent_comments', 'dashboard', 'core');
	remove_meta_box('dashboard_quick_press', 'dashboard', 'core');
	remove_meta_box('dashboard_primary', 'dashboard', 'core');			
}
add_action('admin_menu', 'disable_default_dashboard_widgets');


function excerpt_count_js(){
	global $post;
	if ($post->post_type=='post' || $post->post_type=='longform' ) { 
			echo '<script>jQuery(document).ready(function(){
			jQuery("#postexcerpt .handlediv").after("<div style=\"position:absolute;top:12px;right:34px;color:#666;\"><small>Character count: </small><span id=\"excerpt_counter\"></span><span style=\"font-weight:bold; padding-left:7px;\">/ 140</span><small><span style=\"font-weight:bold; padding-left:7px;\">(limit)</span></small></div>");
				 jQuery("span#excerpt_counter").text(jQuery("#excerpt").val().length);
				 jQuery("#excerpt").keyup( function() {
					 if(jQuery(this).val().length > 140){
						jQuery(this).val(jQuery(this).val().substr(0, 140));
					}
				 jQuery("span#excerpt_counter").text(jQuery("#excerpt").val().length);
			   });
			});</script>';
		}
}
add_action( 'admin_head-post.php', 'excerpt_count_js');
add_action( 'admin_head-post-new.php', 'excerpt_count_js');

add_filter('manage_posts_columns', 'posts_columns', 5);
add_action('manage_posts_custom_column', 'posts_custom_columns', 5, 2);
 
function posts_columns($defaults){
    $defaults['riv_post_thumbs'] = __('Image', 'basics');
    return $defaults;
}
 
function posts_custom_columns($column_name, $id){
    if($column_name === 'riv_post_thumbs'){
        echo the_post_thumbnail( 'featured-thumbnail' );
    }
}
function remove_pages_count_columns($defaults) {
  unset($defaults['comments']);
  return $defaults;
}
add_filter('manage_pages_columns', 'remove_pages_count_columns');
function remove_post_columns($defaults) {
  unset($defaults['comments']);
  return $defaults;
}
add_filter('manage_posts_columns', 'remove_post_columns');

//Breadcrumb
function get_breadcrumb() {
    echo '<a href="'.home_url().'" rel="nofollow">Accueil</a>';
    if (is_category() || is_single()) {
        echo "&nbsp;&nbsp;>&nbsp;&nbsp;";
        the_category(' &bull; ');
    } 
}
//Premier Tag
function basics_first_post_tag_link()
{
    if ( $posttags = get_the_tags() ) 
    {
        $tag = current( $posttags );
        printf(
            '<a href="%1$s">%2$s</a>',
            get_tag_link( $tag->term_id ),
            esc_html( $tag->name )
         );
    }
}
//Protected page
function the_title_trim($title) {

	$title = esc_attr($title);

	$findthese = array(
		'#Protected:#',
		'#Private:#'
	);

	$replacewith = array(
		'', // What to replace "Protected:" with
		'' // What to replace "Private:" with
	);

	$title = preg_replace($findthese, $replacewith, $title);
	return $title;
}
add_filter('the_title', 'the_title_trim');

//Active menu
add_filter('nav_menu_css_class' , 'special_nav_class' , 10 , 2);

function special_nav_class ($classes, $item) {
    if (in_array('current-menu-item', $classes) ){
        $classes[] = 'active ';
    }
    return $classes;
}
require_once( get_template_directory() . '/inc/metadata/metadata_init.php' );
require_once( get_template_directory() . '/inc/walker.php' );
?>